==> openshift-model-machine-6.3.1-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/ObjectMetaFluentImpl.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import java.lang.SuppressWarnings;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.OwnerReference;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ObjectMetaFluentImpl<A extends ObjectMetaFluent<A>> extends BaseFluent<A> implements ObjectMetaFluent<A>{
  public ObjectMetaFluentImpl() {
  }
  public ObjectMetaFluentImpl(ObjectMeta instance) {
    this.withAnnotations(instance.getAnnotations()); 
    this.withGenerateName(instance.getGenerateName()); 
    this.withLabels(instance.getLabels()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withOwnerReferences(instance.getOwnerReferences()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private Map<String,String> annotations;
  private String generateName;
  private Map<String,String> labels;
  private String name;
  private String namespace;
  private List<OwnerReference> ownerReferences = new ArrayList<OwnerReference>();
  private Map<String,Object> additionalProperties;
  public A addToAnnotations(String key,String value) {
    if(this.annotations == null && key != null && value != null) { this.annotations = new LinkedHashMap(); }
    if(key != null && value != null) {this.annotations.put(key, value);} return (A)this;
  }
  public A addToAnnotations(Map<String,String> map) {
    if(this.annotations == null && map != null) { this.annotations = new LinkedHashMap(); }
    if(map != null) { this.annotations.putAll(map);} return (A)this;
  }
  public A removeFromAnnotations(String key) {
    if(this.annotations == null) { return (A) this; }
    if(key != null && this.annotations != null) {this.annotations.remove(key);} return (A)this;
  }
  public A removeFromAnnotations(Map<String,String> map) {
    if(this.annotations == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.annotations != null){this.annotations.remove(key);}}} return (A)this;
  }
  public Map<String,String> getAnnotations() {
    return this.annotations;
  }
  public <K,V>A withAnnotations(Map<String,String> annotations) {
    if (annotations == null) { this.annotations =  null;} else {this.annotations = new LinkedHashMap(annotations);} return (A) this;
  }
  public Boolean hasAnnotations() {
    return this.annotations != null;
  }
  public String getGenerateName() {
    return this.generateName;
  }
  public A withGenerateName(String generateName) {
    this.generateName=generateName; return (A) this;
  }
  public Boolean hasGenerateName() {
    return this.generateName != null;
  }
  public A addToLabels(String key,String value) {
    if(this.labels == null && key != null && value != null) { this.labels = new LinkedHashMap(); }
    if(key != null && value != null) {this.labels.put(key, value);} return (A)this;
  }
  public A addToLabels(Map<String,String> map) {
    if(this.labels == null && map != null) { this.labels = new LinkedHashMap(); }
    if(map != null) { this.labels.putAll(map);} return (A)this;
  }
  public A removeFromLabels(String key) {
    if(this.labels == null) { return (A) this; }
    if(key != null && this.labels != null) {this.labels.remove(key);} return (A)this;
  }
  public A removeFromLabels(Map<String,String> map) {
    if(this.labels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labels != null){this.labels.remove(key);}}} return (A)this;
  }
  public Map<String,String> getLabels() {
    return this.labels;
  }
  public <K,V>A withLabels(Map<String,String> labels) {
    if (labels == null) { this.labels =  null;} else {this.labels = new LinkedHashMap(labels);} return (A) this;
  }
  public Boolean hasLabels() {
    return this.labels != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public Boolean hasNamespace() {
    return this.namespace != null;
  }
  public A addToOwnerReferences(Integer index,OwnerReference item) {
    if (this.ownerReferences == null) {this.ownerReferences = new ArrayList<OwnerReference>();}
    this.ownerReferences.add(index, item);
    return (A)this;
  }
  public A setToOwnerReferences(Integer index,OwnerReference item) {
    if (this.ownerReferences == null) {this.ownerReferences = new ArrayList<OwnerReference>();}
    this.ownerReferences.set(index, item); return (A)this;
  }
  public A addToOwnerReferences(io.fabric8.kubernetes.api.model.OwnerReference... items) {
    if (this.ownerReferences == null) {this.ownerReferences = new ArrayList<OwnerReference>();}
    for (OwnerReference item : items) {this.ownerReferences.add(item);} return (A)this;
  }
  public A addAllToOwnerReferences(Collection<OwnerReference> items) {
    if (this.ownerReferences == null) {this.ownerReferences = new ArrayList<OwnerReference>();}
    for (OwnerReference item : items) {this.ownerReferences.add(item);} return (A)this;
  }
  public A removeFromOwnerReferences(io.fabric8.kubernetes.api.model.OwnerReference... items) {
    for (OwnerReference item : items) {if (this.ownerReferences!= null){ this.ownerReferences.remove(item);}} return (A)this;
  }
  public A removeAllFromOwnerReferences(Collection<OwnerReference> items) {
    for (OwnerReference item : items) {if (this.ownerReferences!= null){ this.ownerReferences.remove(item);}} return (A)this;
  }
  public List<OwnerReference> getOwnerReferences() {
    return this.ownerReferences;
  }
  public OwnerReference getOwnerReference(Integer index) {
    return this.ownerReferences.get(index);
  }
  public OwnerReference getFirstOwnerReference() {
    return this.ownerReferences.get(0);
  }
  public OwnerReference getLastOwnerReference() {
    return this.ownerReferences.get(ownerReferences.size() - 1);
  }
  public OwnerReference getMatchingOwnerReference(Predicate<OwnerReference> predicate) {
    for (OwnerReference item: ownerReferences) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingOwnerReference(Predicate<OwnerReference> predicate) {
    for (OwnerReference item: ownerReferences) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withOwnerReferences(List<OwnerReference> ownerReferences) {
    if (ownerReferences != null) {this.ownerReferences = new ArrayList(); for (OwnerReference item : ownerReferences){this.addToOwnerReferences(item);}} else { this.ownerReferences = null;} return (A) this;
  }
  public A withOwnerReferences(io.fabric8.kubernetes.api.model.OwnerReference... ownerReferences) {
    if (this.ownerReferences != null) {this.ownerReferences.clear();}
    if (ownerReferences != null) {for (OwnerReference item :ownerReferences){ this.addToOwnerReferences(item);}} return (A) this;
  }
  public Boolean hasOwnerReferences() {
    return ownerReferences != null && !ownerReferences.isEmpty();
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ObjectMetaFluentImpl that = (ObjectMetaFluentImpl) o;
    if (annotations != null ? !annotations.equals(that.annotations) :that.annotations != null) return false;
    if (generateName != null ? !generateName.equals(that.generateName) :that.generateName != null) return false;
    if (labels != null ? !labels.equals(that.labels) :that.labels != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
    if (ownerReferences != null ? !ownerReferences.equals(that.ownerReferences) :that.ownerReferences != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(annotations,  generateName,  labels,  name,  namespace,  ownerReferences,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (annotations != null && !annotations.isEmpty()) { sb.append("annotations:"); sb.append(annotations + ","); }
    if (generateName != null) { sb.append("generateName:"); sb.append(generateName + ","); }
    if (labels != null && !labels.isEmpty()) { sb.append("labels:"); sb.append(labels + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (namespace != null) { sb.append("namespace:"); sb.append(namespace + ","); }
    if (ownerReferences != null && !ownerReferences.isEmpty()) { sb.append("ownerReferences:"); sb.append(ownerReferences + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-machine-6.7.2-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/ObjectMetaFluentImpl.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import java.lang.SuppressWarnings;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.OwnerReference;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ObjectMetaFluentImpl<A extends ObjectMetaFluent<A>> extends BaseFluent<A> implements ObjectMetaFluent<A>{
  public ObjectMetaFluentImpl() {
  }
  public ObjectMetaFluentImpl(ObjectMeta instance) {
    if (instance != null) {
      this.withAnnotations(instance.getAnnotations());
      this.withGenerateName(instance.getGenerateName());
      this.withLabels(instance.getLabels());
      this.withName(instance.getName());
      this.withNamespace(instance.getNamespace());
      this.withOwnerReferences(instance.getOwnerReferences());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Map<String,String> annotations;
  private String generateName;
  private Map<String,String> labels;
  private String name;
  private String namespace;
  private List<OwnerReference> ownerReferences = new ArrayList<OwnerReference>();
  private Map<String,Object> additionalProperties;
  public A addToAnnotations(String key,String value) {
    if(this.annotations == null && key != null && value != null) { this.annotations = new LinkedHashMap(); }
    if(key != null && value != null) {this.annotations.put(key, value);} return (A)this;
  }
  public A addToAnnotations(Map<String,String> map) {
    if(this.annotations == null && map != null) { this.annotations = new LinkedHashMap(); }
    if(map != null) { this.annotations.putAll(map);} return (A)this;
  }
  public A removeFromAnnotations(String key) {
    if(this.annotations == null) { return (A) this; }
    if(key != null && this.annotations != null) {this.annotations.remove(key);} return (A)this;
  }
  public A removeFromAnnotations(Map<String,String> map) {
    if(this.annotations == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.annotations != null){this.annotations.remove(key);}}} return (A)this;
  }
  public Map<String,String> getAnnotations() {
    return this.annotations;
  }
  public <K,V>A withAnnotations(Map<String,String> annotations) {
    if (annotations == null) { this.annotations =  null;} else {this.annotations = new LinkedHashMap(annotations);} return (A) this;
  }
  public Boolean hasAnnotations() {
    return this.annotations != null;
  }
  public String getGenerateName() {
    return this.generateName;
  }
  public A withGenerateName(String generateName) {
    this.generateName=generateName; return (A) this;
  }
  public Boolean hasGenerateName() {
    return this.generateName != null;
  }
  public A addToLabels(String key,String value) {
    if(this.labels == null && key != null && value != null) { this.labels = new LinkedHashMap(); }
    if(key != null && value != null) {this.labels.put(key, value);} return (A)this;
  }
  public A addToLabels(Map<String,String> map) {
    if(this.labels == null && map != null) { this.labels = new LinkedHashMap(); }
    if(map != null) { this.labels.putAll(map);} return (A)this;
  }
  public A removeFromLabels(String key) {
    if(this.labels == null) { return (A) this; }
    if(key != null && this.labels != null) {this.labels.remove(key);} return (A)this;
  }
  public A removeFromLabels(Map<String,String> map) {
    if(this.labels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labels != null){this.labels.remove(key);}}} return (A)this;
  }
  public Map<String,String> getLabels() {
    return this.labels;
  }
  public <K,V>A withLabels(Map<String,String> labels) {
    if (labels == null) { this.labels =  null;} else {this.labels = new LinkedHashMap(labels);} return (A) this;
  }
  public Boolean hasLabels() {
    return this.labels != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public Boolean hasNamespace() {
    return this.namespace != null;
  }
  public A addToOwnerReferences(int index,OwnerReference item) {
    if (this.ownerReferences == null) {this.ownerReferences = new ArrayList<OwnerReference>();}
    this.ownerReferences.add(index, item);
    return (A)this;
  }
  public A setToOwnerReferences(int index,OwnerReference item) {
    if (this.ownerReferences == null) {this.ownerReferences = new ArrayList<OwnerReference>();}
    this.ownerReferences.set(index, item); return (A)this;
  }
  public A addToOwnerReferences(io.fabric8.kubernetes.api.model.OwnerReference... items) {
    if (this.ownerReferences == null) {this.ownerReferences = new ArrayList<OwnerReference>();}
    for (OwnerReference item : items) {this.ownerReferences.add(item);} return (A)this;
  }
  public A addAllToOwnerReferences(Collection<OwnerReference> items) {
    if (this.ownerReferences == null) {this.ownerReferences = new ArrayList<OwnerReference>();}
    for (OwnerReference item : items) {this.ownerReferences.add(item);} return (A)this;
  }
  public A removeFromOwnerReferences(io.fabric8.kubernetes.api.model.OwnerReference... items) {
    for (OwnerReference item : items) {if (this.ownerReferences!= null){ this.ownerReferences.remove(item);}} return (A)this;
  }
  public A removeAllFromOwnerReferences(Collection<OwnerReference> items) {
    for (OwnerReference item : items) {if (this.ownerReferences!= null){ this.ownerReferences.remove(item);}} return (A)this;
  }
  public List<OwnerReference> getOwnerReferences() {
    return this.ownerReferences;
  }
  public OwnerReference getOwnerReference(int index) {
    return this.ownerReferences.get(index);
  }
  public OwnerReference getFirstOwnerReference() {
    return this.ownerReferences.get(0);
  }
  public OwnerReference getLastOwnerReference() {
    return this.ownerReferences.get(ownerReferences.size() - 1);
  }
  public OwnerReference getMatchingOwnerReference(Predicate<OwnerReference> predicate) {
    for (OwnerReference item: ownerReferences) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingOwnerReference(Predicate<OwnerReference> predicate) {
    for (OwnerReference item: ownerReferences) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withOwnerReferences(List<OwnerReference> ownerReferences) {
    if (ownerReferences != null) {this.ownerReferences = new ArrayList(); for (OwnerReference item : ownerReferences){this.addToOwnerReferences(item);}} else { this.ownerReferences = null;} return (A) this;
  }
  public A withOwnerReferences(io.fabric8.kubernetes.api.model.OwnerReference... ownerReferences) {
    if (this.ownerReferences != null) {this.ownerReferences.clear(); _visitables.remove("ownerReferences"); }
    if (ownerReferences != null) {for (OwnerReference item :ownerReferences){ this.addToOwnerReferences(item);}} return (A) this;
  }
  public Boolean hasOwnerReferences() {
    return ownerReferences != null && !ownerReferences.isEmpty();
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ObjectMetaFluentImpl that = (ObjectMetaFluentImpl) o;
    if (!java.util.Objects.equals(annotations, that.annotations)) return false;

    if (!java.util.Objects.equals(generateName, that.generateName)) return false;

    if (!java.util.Objects.equals(labels, that.labels)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(namespace, that.namespace)) return false;

    if (!java.util.Objects.equals(ownerReferences, that.ownerReferences)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(annotations,  generateName,  labels,  name,  namespace,  ownerReferences,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (annotations != null && !annotations.isEmpty()) { sb.append("annotations:"); sb.append(annotations + ","); }
    if (generateName != null) { sb.append("generateName:"); sb.append(generateName + ","); }
    if (labels != null && !labels.isEmpty()) { sb.append("labels:"); sb.append(labels + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (namespace != null) { sb.append("namespace:"); sb.append(namespace + ","); }
    if (ownerReferences != null && !ownerReferences.isEmpty()) { sb.append("ownerReferences:"); sb.append(ownerReferences + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
